
Changelog
=========

0.1 - 2017-05-14
----------------

    Initial version


Copyright (C) 2015-2017 Georges Bossert
Copying and distribution of this file, with or without modification, are
permitted provided the copyright notice and this notice are preserved.
